diff -ruN linux-2.6.1/arch/i386/kernel/entry.S linux-2.6.1-dcl/arch/i386/kernel/entry.S
--- linux-2.6.1/arch/i386/kernel/entry.S	2003-12-17 20:58:30.000000000 -0600
+++ linux-2.6.1-dcl/arch/i386/kernel/entry.S	2004-01-30 20:48:55.000000000 -0600
@@ -882,5 +882,6 @@
 	.long sys_utimes
  	.long sys_fadvise64_64
 	.long sys_ni_syscall	/* sys_vserver */
+	.long sys_disablenetwork
 
 syscall_table_size=(.-sys_call_table)
diff -ruN linux-2.6.1/include/asm-i386/unistd.h linux-2.6.1-dcl/include/asm-i386/unistd.h
--- linux-2.6.1/include/asm-i386/unistd.h	2003-12-17 20:59:05.000000000 -0600
+++ linux-2.6.1-dcl/include/asm-i386/unistd.h	2004-01-30 20:43:46.000000000 -0600
@@ -279,8 +279,9 @@
 #define __NR_utimes		271
 #define __NR_fadvise64_64	272
 #define __NR_vserver		273
+#define __NR_disablenetwork	274
 
-#define NR_syscalls 274
+#define NR_syscalls 275
 
 /* user-visible error numbers are in the range -1 - -124: see <asm-i386/errno.h> */
 
diff -ruN linux-2.6.1/include/linux/sched.h linux-2.6.1-dcl/include/linux/sched.h
--- linux-2.6.1/include/linux/sched.h	2004-01-30 22:50:46.000000000 -0600
+++ linux-2.6.1-dcl/include/linux/sched.h	2004-01-30 21:07:37.000000000 -0600
@@ -463,6 +463,7 @@
 
 	unsigned long ptrace_message;
 	siginfo_t *last_siginfo; /* For ptrace use.  */
+	int network_disabled; /* for disablenetwork() syscall */
 };
 
 static inline pid_t process_group(struct task_struct *tsk)
--- linux-2.6.1/net/socket.c	2004-01-30 23:31:40.000000000 -0600
+++ linux-2.6.1-dcl/net/socket.c	2004-01-30 23:32:19.000000000 -0600
@@ -1087,6 +1087,9 @@
 	int retval;
 	struct socket *sock;
 
+	if (current->network_disabled && family != AF_UNIX)
+		goto out_eacces;
+	
 	retval = sock_create(family, type, protocol, &sock);
 	if (retval < 0)
 		goto out;
@@ -1102,6 +1105,9 @@
 out_release:
 	sock_release(sock);
 	return retval;
+
+out_eacces:
+	return -EACCES;
 }
 
 /*
@@ -1187,6 +1193,8 @@
 	if((sock = sockfd_lookup(fd,&err))!=NULL)
 	{
 		if((err=move_addr_to_kernel(umyaddr,addrlen,address))>=0) {
+			if (current->network_disabled && ((struct sockaddr *)address)->sa_family != AF_UNIX)
+				goto out_eacces;
 			err = security_socket_bind(sock, (struct sockaddr *)address, addrlen);
 			if (err) {
 				sockfd_put(sock);
@@ -1197,6 +1205,8 @@
 		sockfd_put(sock);
 	}			
 	return err;
+out_eacces:
+	return -EACCES;
 }
 
 
@@ -1317,7 +1327,7 @@
 	struct socket *sock;
 	char address[MAX_SOCK_ADDR];
 	int err;
-
+	
 	sock = sockfd_lookup(fd, &err);
 	if (!sock)
 		goto out;
@@ -1325,6 +1335,9 @@
 	if (err < 0)
 		goto out_put;
 
+	if (current->network_disabled && ((struct sockaddr *)address)->sa_family != AF_UNIX)
+		goto out_eacces;
+
 	err = security_socket_connect(sock, (struct sockaddr *)address, addrlen);
 	if (err)
 		goto out_put;
@@ -1335,6 +1348,8 @@
 	sockfd_put(sock);
 out:
 	return err;
+out_eacces:
+	return -EACCES;
 }
 
 /*
@@ -1425,6 +1440,9 @@
 		err = move_addr_to_kernel(addr, addr_len, address);
 		if (err < 0)
 			goto out_put;
+		if (current->network_disabled && ((struct sockaddr *) address)->sa_family != AF_UNIX)
+			goto out_eacces;
+
 		msg.msg_name=address;
 		msg.msg_namelen=addr_len;
 	}
@@ -1437,6 +1455,8 @@
 	sockfd_put(sock);
 out:
 	return err;
+out_eacces:
+	return -EACCES;
 }
 
 /*
@@ -1992,6 +2012,11 @@
 }
 #endif /* CONFIG_PROC_FS */
 
+asmlinkage void sys_disablenetwork(void)
+{
+	current->network_disabled = 1;
+}
+
 /* ABI emulation layers need these two */
 EXPORT_SYMBOL(move_addr_to_kernel);
 EXPORT_SYMBOL(move_addr_to_user);
